import { useState, useEffect } from 'react';
import PostForm from './PostForm';
import SearchForm from './SearchForm';
import PostList from './PostList';
import Greeting from './Greeting';
import GraphContainer from './GraphContainer';
import { API_URL } from '../config';
import '../App.css';

function App() {
  const [posts, setPosts] = useState([]);
  const [searchResults, setSearchResults] = useState([]);
  const [userVector, setUserVector] = useState(
    JSON.parse(localStorage.getItem('userVector')) || null
  );

  useEffect(() => {
    loadPosts();
  }, []);

  const loadPosts = async () => {
    try {
      const response = await fetch(`${API_URL}/posts/`);
      const data = await response.json();
      setPosts(data);
    } catch (error) {
      console.error('Error loading posts:', error);
    }
  };

  return (
    <div className="app">
      <Greeting show={!userVector} />
      
      {userVector && <GraphContainer vector={userVector} />}

      <PostForm 
        onPostCreated={(vector) => {
          localStorage.setItem('userVector', JSON.stringify(vector));
          setUserVector(vector);
          loadPosts();
        }}
      />

      <SearchForm onSearch={setSearchResults} />
      
      <PostList posts={searchResults.length > 0 ? searchResults : posts} />
    </div>
  );
}

export default App;